@@ -3,7 +3,7 @@
   
   tips <- c(
     "View the Choroplethr documentation at www.Choroplethr.com",
-    "Stuck? Ask a question here: https://stackoverflow.com/questions/tagged/choroplethrthr."
+    "Stuck? Ask a question here: https://stackoverflow.com/questions/tagged/choroplethr."
   )
   
   tip <- sample(tips, 1)
